@@ -40,9 +40,14 @@ try:
     import gettext
     t = gettext.translation ('lilypond', localedir)
     _ = t.ugettext
+    ungettext = t.ungettext
 except:
     def _ (s):
         return s
+    def ungettext (s, p, n):
+        if n == 1:
+            return s
+        return p
 underscore = _
 
 # Urg, Python 2.4 does not define stderr/stdout encoding
@@ -63,7 +68,7 @@ def display_encode (s):
     return s.encode (sys.stderr.encoding or 'utf-8', 'replace')
 
 # Lilylib globals.
-program_version = '2.16.2'
+program_version = '2.18.0'
 program_name = os.path.basename (sys.argv[0])
 
 
